pub struct PreparedOwnedFrame { /* private fields */ }Expand description
Prepared owned frame passed from the adapter to an owned core.
Implementations
Sourceimpl PreparedOwnedFrame
impl PreparedOwnedFrame
Sourcepub fn from_validated<W, C>(
frame: UOwnedFrame,
codec: &C,
) -> Result<Self, UStatus>where
W: UWire,
C: UWireMetadataCodecFor<W>,
pub fn from_validated<W, C>(
frame: UOwnedFrame,
codec: &C,
) -> Result<Self, UStatus>where
W: UWire,
C: UWireMetadataCodecFor<W>,
Encodes validated owned frame metadata for a selected wire.
Errors
Returns an error if selected-wire metadata encoding fails.
Sourcepub fn metadata(&self) -> &UFrameMetadata
pub fn metadata(&self) -> &UFrameMetadata
Returns decoded frame metadata.
Sourcepub fn encoded_metadata(&self) -> &[u8] ⓘ
pub fn encoded_metadata(&self) -> &[u8] ⓘ
Returns selected-wire encoded metadata bytes.
Sourcepub fn into_parts(self) -> (UFrameMetadata, Vec<u8>, Option<Bytes>)
pub fn into_parts(self) -> (UFrameMetadata, Vec<u8>, Option<Bytes>)
Consumes this frame and returns its parts.