Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Struct UWireTransport

pub struct UWireTransport<TCore, W, C>
where W: UWire, C: UWireMetadataCodecFor<W>,
{ /* private fields */ }
Generic selected-wire transport adapter.

Implementations

Source

impl<TCore, W, C> UWireTransport<TCore, W, C>
where W: UWire, C: UWireMetadataCodecFor<W>,

pub fn new(core: TCore, wire: W, metadata_codec: C) -> Self

Creates an adapter around a transport core, selected wire marker, and metadata codec.

pub fn with_wire_and_metadata_codec( core: TCore, wire: W, metadata_codec: C, ) -> Self

Creates an adapter with an explicit selected wire and metadata codec.

pub fn core(&self) -> &TCore

Returns the wrapped physical transport core.

pub fn core_mut(&mut self) -> &mut TCore

Returns the wrapped physical transport core mutably.

pub fn metadata_codec(&self) -> &C

Returns the selected metadata codec.

pub fn into_parts(self) -> (TCore, W, C)

Consumes the adapter and returns the wrapped core, selected wire, and metadata codec.