Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Trait UEncodedLoanedRxFrame

pub trait UEncodedLoanedRxFrame: UEncodedRxFrame {
    // Required method
    fn loaned_contiguous_payload(&self) -> Result<LoanedPayload<'_>, UWireError>;
}
Raw encoded receive object that can prove its contiguous payload is loan-backed.

Required Methods

fn loaned_contiguous_payload(&self) -> Result<LoanedPayload<'_>, UWireError>

Returns one contiguous loan-backed application payload view.

Implementations must not allocate, copy, or coalesce payload bytes to satisfy this method.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors