pub trait UHasWire {
type Wire: UWire;
// Required method
fn wire(&self) -> &Self::Wire;
}Expand description
Exposes the concrete selected wire of an adapter value.
native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-uppub trait UHasWire {
type Wire: UWire;
// Required method
fn wire(&self) -> &Self::Wire;
}Exposes the concrete selected wire of an adapter value.