pub struct UWireTransport<TCore, W, C>where
W: UWire,
C: UWireMetadataCodecFor<W>,{ /* private fields */ }Expand description
Generic selected-wire transport adapter.
Implementations
Sourceimpl<TCore, W, C> UWireTransport<TCore, W, C>where
W: UWire,
C: UWireMetadataCodecFor<W>,
impl<TCore, W, C> UWireTransport<TCore, W, C>where
W: UWire,
C: UWireMetadataCodecFor<W>,
Sourcepub fn new(core: TCore, wire: W, metadata_codec: C) -> Self
pub fn new(core: TCore, wire: W, metadata_codec: C) -> Self
Creates an adapter around a transport core, selected wire marker, and metadata codec.
Sourcepub fn with_wire_and_metadata_codec(
core: TCore,
wire: W,
metadata_codec: C,
) -> Self
pub fn with_wire_and_metadata_codec( core: TCore, wire: W, metadata_codec: C, ) -> Self
Creates an adapter with an explicit selected wire and metadata codec.
Sourcepub fn core_mut(&mut self) -> &mut TCore
pub fn core_mut(&mut self) -> &mut TCore
Returns the wrapped physical transport core mutably.
Sourcepub fn metadata_codec(&self) -> &C
pub fn metadata_codec(&self) -> &C
Returns the selected metadata codec.
Sourcepub fn into_parts(self) -> (TCore, W, C)
pub fn into_parts(self) -> (TCore, W, C)
Consumes the adapter and returns the wrapped core, selected wire, and metadata codec.